@@ -19,9 +19,6 @@ class RemoteCall:
         self.service_path = service_path
 
     def func_call(self, params):
-        return self.func_call(params)
-
-    def func_call_new(self, params):
         if type(params) is tuple:
             protocol['args'] = params
         else:
